@@ -2,7 +2,7 @@ Facter.add(:kernel) do
     setcode do
         require 'rbconfig'
         case Config::CONFIG['host_os']
-          when /mswin/i then 'windows'
+          when /mswin/i; 'windows'
           else Facter::Util::Resolution.exec("uname -s")
         end
     end
