@@ -1,3 +1,5 @@
+require 'facter/lsb'
+
 Facter.add(:operatingsystem) do
     confine :kernel => :sunos
     setcode do "Solaris" end
@@ -18,6 +20,12 @@ Facter.add(:operatingsystem) do
             "Mandriva"
         elsif FileTest.exists?("/etc/mandrake-release")
             "Mandrake"
+	elsif FileTest.exists?("/etc/arch-release")
+	    "Archlinux"
+        elsif FileTest.exists?("/etc/enterprise-release")
+            "OEL"
+        elsif FileTest.exists?("/etc/ovs-release")
+            "OVS"
         elsif FileTest.exists?("/etc/redhat-release")
             txt = File.read("/etc/redhat-release")
             if txt =~ /centos/i
@@ -29,6 +37,8 @@ Facter.add(:operatingsystem) do
             txt = File.read("/etc/SuSE-release")
             if txt =~ /^SUSE LINUX Enterprise Server/i
                 "SLES"
+	    elsif txt =~ /^openSUSE/i
+		"OpenSuSE"
             else
                 "SuSE"
             end
